"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "AuthUIContextProvider", {
  enumerable: true,
  get: function () {
    return _provider.AuthUIContextProvider;
  }
});
exports.useInjectedUIContext = void 0;

var _react = require("react");

var _context = require("./context");

var _provider = require("./provider");

/**
 * The AuthUIContextProvider allows for application code to pass in middleware
 * actions that result from the Authentication and Registration user interface.
 * Often the actions will be the local storage and API calls satisfying
 * [[AuthUIActions]] and [[RegistrationUIActions]]. UI configuration properties
 * are also passed in.
 *
 * @packageDocumentation
 * @module AuthUIContextProvider
 * @preferred
 */

/**
 * Allows for the module to grab the properties / actions passed in from the applications.
 *
 * @category Hooks
 * @private
 * @internal
 */
const useInjectedUIContext = () => {
  const context = (0, _react.useContext)(_context.AuthUIContext);

  if (context === null) {
    throw new Error('useInjectedUIContext must be used within an AuthUIContextProvider');
  }

  return context;
};
/** @ignore */


exports.useInjectedUIContext = useInjectedUIContext;
//# sourceMappingURL=index.js.map