"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.reducer = void 0;

/**
 * @packageDocumentation
 * @module SecurityContextProvider
 */

/**
 * @internal
 * @private
 */

/**
 * @internal
 * @private
 *
 * Reducer for [[SecurityContextProvider]].
 *
 * @param prevState Previous [[SecurityContextState]] to update.
 * @param action State change action, which should be of type [[Action]].
 */
const reducer = (prevState, action) => {
  switch (action.type) {
    case 'userAuthenticated':
      return {
        email: action.payload.email,
        userId: action.payload.userId,
        rememberMeDetails: {
          email: action.payload.rememberMe ? action.payload.email : undefined,
          rememberMe: action.payload.rememberMe
        },
        isLoading: false,
        isSignOut: false,
        isAuthenticatedUser: true,
        isShowingChangePassword: false
      };

    case 'userNotAuthenticated':
      {
        var _action$payload$overr, _action$payload$overr2;

        const overrideExists = ((_action$payload$overr = (_action$payload$overr2 = action.payload.overrideRememberMeEmail) === null || _action$payload$overr2 === void 0 ? void 0 : _action$payload$overr2.length) !== null && _action$payload$overr !== void 0 ? _action$payload$overr : 0) > 0;
        let rememberEmail = prevState.rememberMeDetails.email;
        let rememberMe = prevState.rememberMeDetails.rememberMe;

        if (overrideExists) {
          rememberEmail = action.payload.overrideRememberMeEmail;
          rememberMe = true;
        } else if (action.payload.clearRememberMe) {
          rememberEmail = undefined;
          rememberMe = false;
        }

        return {
          email: undefined,
          userId: undefined,
          rememberMeDetails: {
            email: rememberEmail,
            rememberMe: rememberMe
          },
          isLoading: false,
          isSignOut: true,
          isAuthenticatedUser: false,
          isShowingChangePassword: false
        };
      }

    case 'showChangePassword':
      return { ...prevState,
        isShowingChangePassword: true
      };

    case 'hideChangePassword':
      return { ...prevState,
        isShowingChangePassword: false
      };

    default:
      return prevState;
  }
};

exports.reducer = reducer;
//# sourceMappingURL=reducer.js.map